function [es_val, L_val] = moist_ape_es(T_val, thermo_type)

 % Calculate saturation vapor pressure es and the associated latent heat of vaporization L 
 % For the 'full' case, the effects of ice are included following Wang and Randall 1994 but with formulae over ice and liquid that are used for ERA40 (we chose not to use the merging of these profiles implemented in ERA40 because that gave a bump in the profile of L versus temperature)

 error(nargchk(2, 2, nargin))

 switch lower(thermo_type)
  case 'simple'

   es_val = simple_sat_vapor_pressure(T_val);
   L_val  = PARS('l_cond');

  case 'full'

   persistent not_first_call L T es;
  
   if isempty(not_first_call)
  
  
    Tf      = 270.16; % (K) location of freezing zone
    delta_T = 3;      % (K) controls width of freezing zone

    dT      = 0.2; % temperature step
    T       = [350:-dT:50];
  
    % saturation vapor pressure over ice and liquid (Simmons 1999)
    es0       = 611.21;  % saturation vapor pressure at T0 (Pa)
    T0        = 273.16;  % (K)
    a3l       = 17.502;  % liquid water (Buck 1981)
    a4l       = 32.19;   % (K)
    a3i       = 22.587;  % ice (Alduchov and Eskridge 1996)
    a4i       = -0.7;    % (K)
   
    
    esl       = es0 .* exp(a3l .* (T - T0)./(T - a4l));
    esi       = es0 .* exp(a3i .* (T - T0)./(T - a4i));
   
    omega_l = 0.5*(1+tanh((T-Tf)/delta_T));
    omega_i = 1-omega_l;
   
    f_l = T.*log(esl./es0);
    f_i = T.*log(esi./es0);
   
    % solve equation A10 in Wang and Randall 1994 (but noting missing
    % derivatives wrt T)
    f(1) = f_l(1); 
    for k = 2:length(T)
     f(k) = f(k-1) + omega_l(k)*(f_l(k)-f_l(k-1)) + omega_i(k)*(f_i(k)-f_i(k-1));
    end
   
    es = es0*exp(f./T);
  
    % relation A3 in Wang and Randall 1994
    L  = PARS('gas_constant_v')*T.^2.*gradient(log(es), T);
  
    not_first_call = 1;
  
   end
  
   if any(T_val<min(T)| T_val>max(T))
    min(T_val)
    max(T_val)
    error('out of range')
   end
  
   L_val  = interp1(T, L, T_val, 'linear', NaN);
   es_val  = interp1(T, es, T_val, 'linear', NaN);
  
  otherwise
   error(['Unknown type, ', thermo_type, 'of thermodynamic formulation.'])
 end

